@@ -48,10 +48,7 @@ def _create_context_manager():
     global _CTX_MANAGER
     if _CTX_MANAGER is None:
         _CTX_MANAGER = enginefacade.transaction_context()
-        # TODO(stephenfin): Drop "__autocommit=False" when oslo.db changes its
-        # default (https://review.opendev.org/c/openstack/oslo.db/+/804775)
-        _CTX_MANAGER.configure(sqlite_fk=True, flush_on_subtransaction=True,
-                               __autocommit=False)
+        _CTX_MANAGER.configure(sqlite_fk=True, flush_on_subtransaction=True)
 
     return _CTX_MANAGER
 
@@ -309,7 +306,7 @@ def _load_one_to_manys(session):
     if session.new:
         session.flush()
 
-    if session.transaction.nested:
+    if session.get_transaction().nested:
         # wait until final commit
         return
 
@@ -333,7 +330,8 @@ def _load_one_to_manys(session):
         # identity map and not emit SELECT.  Otherwise, we are still
         # local in the transaction so a normal SELECT load will work fine.
         for relationship_attr in state.mapper.relationships:
-            if relationship_attr.lazy not in ('joined', 'subquery'):
+            if relationship_attr.lazy not in ('joined', 'subquery',
+                                              'selectin'):
                 # we only want to automatically load relationships that would
                 # automatically load during a lookup operation
                 continue
@@ -479,8 +477,8 @@ def is_session_active(session):
     if getattr(session, 'autocommit', None):
         # old behaviour, to be removed with sqlalchemy 2.0
         return session.is_active
-    if not session.transaction:
+    if not session.get_transaction():
         return False
-    if not session.transaction._connections:
+    if not session.get_transaction()._connections:
         return False
     return True
