@@ -12,11 +12,10 @@
 
 import functools
 
-from oslo_config import cfg
 from oslo_db import exception as db_exc
 from oslo_utils import excutils
 import sqlalchemy
-from sqlalchemy.ext.associationproxy import ASSOCIATION_PROXY
+from sqlalchemy.ext import associationproxy
 from sqlalchemy.orm import exc
 from sqlalchemy.orm import properties
 
@@ -152,11 +151,17 @@ def filter_non_model_columns(data, model):
         proxies of the model.
     """
     mapper = sqlalchemy.inspect(model)
-    columns = set(c.name for c in mapper.columns)
+    columns = {c.name for c in mapper.columns}
+    try:
+        _association_proxy = associationproxy.ASSOCIATION_PROXY
+    except AttributeError:
+        # SQLAlchemy 2.0
+        _association_proxy = (
+            associationproxy.AssociationProxyExtensionType.ASSOCIATION_PROXY)
     columns.update(d.value_attr for d in mapper.all_orm_descriptors
-                   if d.extension_type is ASSOCIATION_PROXY)
-    return dict((k, v) for (k, v)
-                in data.items() if k in columns)
+                   if d.extension_type is _association_proxy)
+    return {k: v for (k, v)
+            in data.items() if k in columns}
 
 
 def model_query_scope_is_project(context, model):
@@ -168,24 +173,16 @@ def model_query_scope_is_project(context, model):
         has a project_id. False otherwise.
     """
     if not hasattr(model, 'project_id'):
-        # If model don't have project_id, there is no need to scope query to
+        # If model doesn't have project_id, there is no need to scope query to
         # just one project
         return False
-    if context.is_advsvc:
+    if context.is_service_role:
         # For context which has 'advanced-service' rights the
         # query will not be scoped to a single project_id
         return False
-    # TODO(slaweq): Remove that old is_admin check and always check scopes
-    # when old, deprecated rules will be removed and only rules with new
-    # personas will be supported
-    if cfg.CONF.oslo_policy.enforce_scope:
-        # Unless a context is a system_scope token, query should be scoped to a
-        # single project_id
-        return context.system_scope != 'all'
-    else:
-        # Unless context has 'admin' rights the
-        # query will be scoped to a single project_id
-        return not context.is_admin
+    # Unless context has 'admin' rights the
+    # query will be scoped to a single project_id
+    return not context.is_admin
 
 
 def model_query(context, model):
@@ -199,7 +196,7 @@ def model_query(context, model):
     # define basic filter condition for model query
     query_filter = None
     if model_query_scope_is_project(context, model):
-        query_filter = (model.tenant_id == context.tenant_id)
+        query_filter = (model.tenant_id == context.project_id)
 
     if query_filter is not None:
         query = query.filter(query_filter)
