@@ -12,6 +12,8 @@
 
 import importlib.util
 import os
+import types
+import typing
 
 from neutron_lib.api import definitions
 from neutron_lib.api.definitions import base
@@ -23,7 +25,7 @@ from neutron_lib.tests import _base as test_base
 def assert_bool(tester, attribute, attribute_dict, keyword, value):
     tester.assertIsInstance(
         value, bool,
-        '%s must be a boolean for %s.' % (keyword, attribute))
+        '{} must be a boolean for {}.'.format(keyword, attribute))
 
 
 def assert_converter(tester, attribute, attribute_dict, keyword, value):
@@ -45,12 +47,13 @@ def assert_converter(tester, attribute, attribute_dict, keyword, value):
 
 def assert_true(tester, attribute, attribute_dict, keyword, value):
     tester.assertTrue(
-        value, '%s must be True for %s.' % (keyword, attribute))
+        value, '{} must be True for {}.'.format(keyword, attribute))
 
 
 def assert_validator(tester, attribute, attribute_dict, keyword, value):
     tester.assertIn(list(value)[0], validators.validators,
-                    '%s is not a known validator for %s.' % (value, attribute))
+                    '{} is not a known validator for {}.'.format(
+                        value, attribute))
 
 
 ASSERT_FUNCTIONS = {
@@ -73,13 +76,13 @@ ASSERT_FUNCTIONS = {
 
 class DefinitionBaseTestCase(test_base.BaseTestCase):
 
-    extension_module = None
-    extension_resources = ()
-    extension_subresources = ()
-    extension_attributes = ()
+    extension_module: typing.Optional[types.ModuleType] = None
+    extension_resources: tuple[str, ...] = ()
+    extension_subresources: tuple[str, ...] = ()
+    extension_attributes: tuple[str, ...] = ()
 
     def setUp(self):
-        super(DefinitionBaseTestCase, self).setUp()
+        super().setUp()
         if not self.extension_module:
             self.fail("Missing extension module definition.")
         self.alias = self.extension_module.ALIAS
