@@ -14,6 +14,7 @@
 
 from unittest import mock
 
+import ddt
 from oslo_db import exception as db_exc
 from oslotest import base
 
@@ -29,7 +30,7 @@ PRI_MED = 5000
 PRI_LOW = 10000
 
 
-class ObjectWithCallback(object):
+class ObjectWithCallback:
 
     def __init__(self):
         self.counter = 0
@@ -64,27 +65,38 @@ def callback_raise_retriable(*args, **kwargs):
     raise db_exc.DBDeadlock()
 
 
+def callback_raise_not_retriable(*args, **kwargs):
+    raise Exception()
+
+
 def callback_3(resource, event, trigger, payload):
     callback_3.counter += 1
 
 
+@ddt.ddt
 class CallBacksManagerTestCase(base.BaseTestCase):
 
     def setUp(self):
-        super(CallBacksManagerTestCase, self).setUp()
+        super().setUp()
         self.manager = manager.CallbacksManager()
+        self.event_payload = events.EventPayload(object())
         callback_1.counter = 0
         callback_2.counter = 0
         callback_3.counter = 0
 
-    def test_subscribe(self):
+    @ddt.data(True, False)
+    def test_subscribe(self, cancellable):
         self.manager.subscribe(
-            callback_1, resources.PORT, events.BEFORE_CREATE)
+            callback_1, resources.PORT, events.BEFORE_CREATE,
+            cancellable=cancellable)
         self.assertIsNotNone(
             self.manager._callbacks[resources.PORT][events.BEFORE_CREATE])
         self.assertIn(callback_id_1, self.manager._index)
         self.assertEqual(self.__module__ + '.callback_1-%s' %
                          hash(callback_1), callback_id_1)
+        self.assertEqual(cancellable,
+                         self.manager._callbacks[resources.PORT]
+                         [events.BEFORE_CREATE][0][2])
 
     def test_subscribe_unknown(self):
         self.manager.subscribe(
@@ -94,13 +106,19 @@ class CallBacksManagerTestCase(base.BaseTestCase):
         self.assertIn(callback_id_1, self.manager._index)
 
     def test_subscribe_is_idempotent(self):
-        self.manager.subscribe(
-            callback_1, resources.PORT, events.BEFORE_CREATE)
-        self.manager.subscribe(
-            callback_1, resources.PORT, events.BEFORE_CREATE)
+        for cancellable in (True, False):
+            self.manager.subscribe(
+                callback_1, resources.PORT, events.BEFORE_CREATE,
+                cancellable=cancellable)
+            self.manager.subscribe(
+                callback_1, resources.PORT, events.BEFORE_CREATE,
+                cancellable=cancellable)
         self.assertEqual(
             1,
             len(self.manager._callbacks[resources.PORT][events.BEFORE_CREATE]))
+        # The first event registered had cancellable=True.
+        self.assertTrue(self.manager._callbacks[resources.PORT]
+                        [events.BEFORE_CREATE][0][2])
         callbacks = self.manager._index[callback_id_1][resources.PORT]
         self.assertEqual(1, len(callbacks))
 
@@ -124,12 +142,15 @@ class CallBacksManagerTestCase(base.BaseTestCase):
 
         self.manager.subscribe(unsub, resources.PORT,
                                events.BEFORE_CREATE)
-        self.manager.notify(resources.PORT, events.BEFORE_CREATE, mock.ANY)
+        self.manager.publish(resources.PORT, events.BEFORE_CREATE, mock.ANY,
+                             payload=self.event_payload)
         self.assertNotIn(unsub, self.manager._index)
 
-    def test_unsubscribe(self):
+    @ddt.data(True, False)
+    def test_unsubscribe(self, cancellable):
         self.manager.subscribe(
-            callback_1, resources.PORT, events.BEFORE_CREATE)
+            callback_1, resources.PORT, events.BEFORE_CREATE,
+            cancellable=cancellable)
         self.manager.unsubscribe(
             callback_1, resources.PORT, events.BEFORE_CREATE)
         self.assertNotIn(
@@ -153,9 +174,11 @@ class CallBacksManagerTestCase(base.BaseTestCase):
                           self.manager.unsubscribe,
                           callback_1, None, events.BEFORE_CREATE)
 
-    def test_unsubscribe_is_idempotent(self):
+    @ddt.data(True, False)
+    def test_unsubscribe_is_idempotent(self, cancellable):
         self.manager.subscribe(
-            callback_1, resources.PORT, events.BEFORE_CREATE)
+            callback_1, resources.PORT, events.BEFORE_CREATE,
+            cancellable=cancellable)
         self.manager.unsubscribe(
             callback_1, resources.PORT, events.BEFORE_CREATE)
         self.manager.unsubscribe(
@@ -199,58 +222,92 @@ class CallBacksManagerTestCase(base.BaseTestCase):
             self.manager._callbacks[resources.PORT][events.BEFORE_CREATE])
         self.assertNotIn(callback_id_1, self.manager._index)
 
-    def test_notify_none(self):
-        self.manager.notify(resources.PORT, events.BEFORE_CREATE, mock.ANY)
+    def test_publish_none(self):
+        self.manager.publish(resources.PORT, events.BEFORE_CREATE, mock.ANY,
+                             payload=self.event_payload)
         self.assertEqual(0, callback_1.counter)
         self.assertEqual(0, callback_2.counter)
 
     def test_feebly_referenced_callback(self):
         self.manager.subscribe(lambda *x, **y: None, resources.PORT,
                                events.BEFORE_CREATE)
-        self.manager.notify(resources.PORT, events.BEFORE_CREATE, mock.ANY)
+        self.manager.publish(resources.PORT, events.BEFORE_CREATE, mock.ANY,
+                             payload=self.event_payload)
 
-    def test_notify_with_exception(self):
+    def test_publish_with_exception(self):
         with mock.patch.object(self.manager, '_notify_loop') as n:
             n.return_value = ['error']
             self.assertRaises(exceptions.CallbackFailure,
-                              self.manager.notify,
-                              mock.ANY, events.BEFORE_CREATE, mock.ANY)
+                              self.manager.publish,
+                              mock.ANY, events.BEFORE_CREATE, mock.ANY,
+                              payload=self.event_payload)
             expected_calls = [
-                mock.call(mock.ANY, 'before_create', mock.ANY),
-                mock.call(mock.ANY, 'abort_create', mock.ANY)
+                mock.call(mock.ANY, 'before_create', mock.ANY,
+                          self.event_payload),
+                mock.call(mock.ANY, 'abort_create', mock.ANY,
+                          self.event_payload)
             ]
             n.assert_has_calls(expected_calls)
 
-    def test_notify_with_precommit_exception(self):
+    def test_publish_with_precommit_exception(self):
         with mock.patch.object(self.manager, '_notify_loop') as n:
             n.return_value = ['error']
             self.assertRaises(exceptions.CallbackFailure,
-                              self.manager.notify,
-                              mock.ANY, events.PRECOMMIT_UPDATE, mock.ANY)
+                              self.manager.publish,
+                              mock.ANY, events.PRECOMMIT_UPDATE, mock.ANY,
+                              payload=self.event_payload)
             expected_calls = [
-                mock.call(mock.ANY, 'precommit_update', mock.ANY),
+                mock.call(mock.ANY, 'precommit_update', mock.ANY,
+                          self.event_payload),
             ]
             n.assert_has_calls(expected_calls)
 
-    def test_notify_handle_exception(self):
+    def test_publish_handle_exception(self):
         self.manager.subscribe(
             callback_raise, resources.PORT, events.BEFORE_CREATE)
-        e = self.assertRaises(exceptions.CallbackFailure, self.manager.notify,
-                              resources.PORT, events.BEFORE_CREATE, self)
+        e = self.assertRaises(exceptions.CallbackFailure, self.manager.publish,
+                              resources.PORT, events.BEFORE_CREATE, self,
+                              payload=self.event_payload)
         self.assertIsInstance(e.errors[0], exceptions.NotificationError)
 
-    def test_notify_handle_retriable_exception(self):
+    def test_publish_handle_retriable_exception(self):
         self.manager.subscribe(
             callback_raise_retriable, resources.PORT, events.BEFORE_CREATE)
-        self.assertRaises(db_exc.RetryRequest, self.manager.notify,
-                          resources.PORT, events.BEFORE_CREATE, self)
+        self.assertRaises(db_exc.RetryRequest, self.manager.publish,
+                          resources.PORT, events.BEFORE_CREATE, self,
+                          payload=self.event_payload)
 
-    def test_notify_called_once_with_no_failures(self):
+    def test_publish_handle_not_retriable_exception(self):
+        self.manager.subscribe(
+            callback_raise_not_retriable, resources.PORT, events.BEFORE_CREATE)
+        self.assertRaises(exceptions.CallbackFailure, self.manager.publish,
+                          resources.PORT, events.BEFORE_CREATE, self,
+                          payload=self.event_payload)
+
+    def test_publish_handle_not_retriable_exception_no_cancellable_flag(self):
+        self.manager.subscribe(
+            callback_raise_not_retriable, resources.PORT, events.AFTER_INIT)
+        # No exception is raised.
+        self.manager.publish(resources.PORT, events.AFTER_INIT, self,
+                             payload=self.event_payload)
+
+    def test_publish_handle_not_retriable_exception_cancellable_flag(self):
+        self.manager.subscribe(
+            callback_raise_not_retriable, resources.PORT, events.AFTER_INIT,
+            cancellable=True)
+        self.assertRaises(exceptions.CallbackFailure, self.manager.publish,
+                          resources.PORT, events.AFTER_INIT, self,
+                          payload=self.event_payload)
+
+    def test_publish_called_once_with_no_failures(self):
         with mock.patch.object(self.manager, '_notify_loop') as n:
             n.return_value = False
-            self.manager.notify(resources.PORT, events.BEFORE_CREATE, mock.ANY)
+            self.manager.publish(resources.PORT, events.BEFORE_CREATE,
+                                 mock.ANY,
+                                 payload=self.event_payload)
             n.assert_called_once_with(
-                resources.PORT, events.BEFORE_CREATE, mock.ANY)
+                resources.PORT, events.BEFORE_CREATE, mock.ANY,
+                self.event_payload)
 
     def test__notify_loop_single_event(self):
         self.manager.subscribe(
@@ -258,7 +315,8 @@ class CallBacksManagerTestCase(base.BaseTestCase):
         self.manager.subscribe(
             callback_2, resources.PORT, events.BEFORE_CREATE)
         self.manager._notify_loop(
-            resources.PORT, events.BEFORE_CREATE, mock.ANY)
+            resources.PORT, events.BEFORE_CREATE, mock.ANY,
+            payload=mock.ANY)
         self.assertEqual(1, callback_1.counter)
         self.assertEqual(1, callback_2.counter)
 
@@ -270,9 +328,11 @@ class CallBacksManagerTestCase(base.BaseTestCase):
         self.manager.subscribe(
             callback_2, resources.PORT, events.BEFORE_CREATE)
         self.manager._notify_loop(
-            resources.PORT, events.BEFORE_CREATE, mock.ANY)
+            resources.PORT, events.BEFORE_CREATE, mock.ANY,
+            payload=mock.ANY)
         self.manager._notify_loop(
-            resources.ROUTER, events.BEFORE_DELETE, mock.ANY)
+            resources.ROUTER, events.BEFORE_DELETE, mock.ANY,
+            payload=mock.ANY)
         self.assertEqual(2, callback_1.counter)
         self.assertEqual(1, callback_2.counter)
 
@@ -320,7 +380,8 @@ class CallBacksManagerTestCase(base.BaseTestCase):
         self.assertEqual(
             3, len(self.manager._callbacks['my-resource']['my-event']))
         self.manager.unsubscribe(callback_3, 'my-resource', 'my-event')
-        self.manager.notify('my-resource', 'my-event', mock.ANY)
+        self.manager.publish('my-resource', 'my-event', mock.ANY,
+                             payload=self.event_payload)
         # callback_3 should be deleted and not executed
         self.assertEqual(
             2, len(self.manager._callbacks['my-resource']['my-event']))
@@ -340,9 +401,10 @@ class CallBacksManagerTestCase(base.BaseTestCase):
         self.manager.subscribe(
             callback_raise, resources.PORT, events.PRECOMMIT_CREATE)
         self.manager._notify_loop(
-            resources.PORT, events.BEFORE_CREATE, mock.ANY)
+            resources.PORT, events.BEFORE_CREATE, mock.ANY, payload=mock.ANY)
         self.manager._notify_loop(
-            resources.PORT, events.PRECOMMIT_CREATE, mock.ANY)
+            resources.PORT, events.PRECOMMIT_CREATE, mock.ANY,
+            payload=mock.ANY)
         self.assertFalse(_logger.exception.call_count)
         self.assertTrue(_logger.debug.call_count)
 
@@ -357,7 +419,8 @@ class CallBacksManagerTestCase(base.BaseTestCase):
             # ensure idempotency remains for a single object
             self.manager.subscribe(
                 o.callback, resources.PORT, events.BEFORE_CREATE)
-        self.manager.notify(resources.PORT, events.BEFORE_CREATE, mock.ANY)
+        self.manager.publish(resources.PORT, events.BEFORE_CREATE, mock.ANY,
+                             payload=events.EventPayload(object()))
         self.assertEqual(1, a.counter)
         self.assertEqual(1, b.counter)
         self.assertEqual(1, c.counter)
@@ -384,6 +447,5 @@ class CallBacksManagerTestCase(base.BaseTestCase):
             notify_payload.append(payload)
 
         self.manager.subscribe(_memo, 'x', 'y')
-        payload = events.EventPayload(object())
-        self.manager.publish('x', 'y', self, payload=payload)
-        self.assertEqual(payload, notify_payload[0])
+        self.manager.publish('x', 'y', self, payload=self.event_payload)
+        self.assertEqual(self.event_payload, notify_payload[0])
